%define url_ver	%(echo %{version} | tr '.' '_')

Summary:	Open source MSX emulator
Name:		openmsx
Version:	20.0
Release:	%mkrel 1
License:	GPLv2+
Group:		Emulators
URL:		https://openmsx.sourceforge.net/
Source0:	https://github.com/openMSX/openMSX/releases/download/RELEASE_%{url_ver}/openmsx-%{version}.tar.gz
BuildRequires:	docbook-utils
BuildRequires:	python3
BuildRequires:	pkgconfig(alsa)
BuildRequires:	pkgconfig(freetype2)
BuildRequires:	pkgconfig(glew)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(ogg)
BuildRequires:	pkgconfig(SDL2_ttf)
BuildRequires:	pkgconfig(tcl)
BuildRequires:	pkgconfig(theora)
BuildRequires:	pkgconfig(vorbis)
BuildRequires:	pkgconfig(libxml-2.0)
Requires:	cbios-openmsx

# Catapult is no longer maintained
Obsoletes:	%{name}-catapult <= 19.1

%description
The open source MSX emulator that tries to achieve
near-perfect emulation by using a novel emulation model.

%files
%doc %{_docdir}/%{name}/
%license doc/GPL.txt
%{_bindir}/openmsx
%{_datadir}/openmsx/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_mandir}/man1/openmsx.1*
%dir %{_sysconfdir}/%{name}/
%config(noreplace) %{_sysconfdir}/%{name}/settings.xml

#--------------------------------------------------------------------

%prep
%autosetup -p1

# Make the custom flavour module, so we can use RPM OPT FLAGS here
cat > build/flavour-rpm.mk << EOF
# Opt flags.
CXXFLAGS+=%{build_cxxflags} -DNDEBUG
LINK_FLAGS+=%{build_ldflags}

# Dont strip exe, let rpm do it and save debug info
OPENMSX_STRIP:=false
EOF

# Build config
cat > build/custom.mk << EOF
PYTHON:=python3
INSTALL_BASE:=%{_prefix}
VERSION_EXEC:=false
SYMLINK_FOR_BINARY:=false
INSTALL_CONTRIB:=false
INSTALL_SHARE_DIR=%{_datadir}/%{name}
INSTALL_DOC_DIR=%{_docdir}/%{name}
EOF

%build
%configure
%make_build OPENMSX_FLAVOUR=rpm V=1

# Build the man page
docbook2man doc/openmsx.sgml -o ./

%install
%make_install OPENMSX_FLAVOUR=rpm V=1

rm -rf $RPM_BUILD_ROOT%{_docdir}/%{name}/GPL.txt

mv $RPM_BUILD_ROOT%{_datadir}/%{name}/machines/*.txt \
   $RPM_BUILD_ROOT%{_docdir}/%{name}

mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/%{name}
mv $RPM_BUILD_ROOT%{_datadir}/%{name}/settings.xml \
   $RPM_BUILD_ROOT%{_sysconfdir}/%{name}
ln -s --target-directory=$RPM_BUILD_ROOT%{_datadir}/%{name} \
   ../../../etc/openmsx/settings.xml

mkdir -p $RPM_BUILD_ROOT%{_mandir}/man1
install -pm 0644 OPENMSX.1 $RPM_BUILD_ROOT%{_mandir}/man1/openmsx.1

# Install icon set
mkdir -p $RPM_BUILD_ROOT%{_datadir}/icons/hicolor/{16x16,32x32,48x48,64x64,128x128}/apps
for i in 16 32 48 64 128; do
install -pm 0644 share/icons/openMSX-logo-"$i".png \
    $RPM_BUILD_ROOT%{_datadir}/icons/hicolor/"$i"x"$i"/apps/%{name}.png
done

# Install desktop file
mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{name}.desktop <<EOF
[Desktop Entry]
Name=openMSX
GenericName=MSX Emulator
Comment=Graphical interface for openMSX
Exec=%{name}
Icon=%{name}
Terminal=false
Type=Application
Categories=Game;Emulator;
Keywords=emulator;msx;openmsx;
EOF


%changelog
* Fri Dec 06 2024 daviddavid <daviddavid> 20.0-1.mga10
+ Revision: 2122137
- new version: 20.0
- catapult is no longer maintained and was deprecated in favor to
  introduce the new Graphical User Interface

* Mon Jul 08 2024 papoteur <papoteur> 19.1-1.mga10
+ Revision: 2080355
- new version 19.1

* Fri Jul 15 2022 wally <wally> 18.0-2.mga9
+ Revision: 1868995
- rebuild for wxgtk 3.2.0

* Sat Jun 25 2022 wally <wally> 18.0-1.mga9
+ Revision: 1866190
- new version 18.0

* Sun Jun 12 2022 wally <wally> 17.0-6.mga9
+ Revision: 1864103
- rebuild for wxgtk 3.1.7

* Fri Apr 15 2022 wally <wally> 17.0-5.mga9
+ Revision: 1849984
- rebuild for wxgtk 3.1.6

* Mon Apr 04 2022 umeabot <umeabot> 17.0-4.mga9
+ Revision: 1844061
- Mageia 9 Mass Rebuild

* Sat Jan 15 2022 wally <wally> 17.0-3.mga9
+ Revision: 1768511
- rebuild for wxgtk 3.1.5 with working wxSizer::SetSizeHints()

* Sat Jan 01 2022 wally <wally> 17.0-2.mga9
+ Revision: 1765700
- rebuild for wxgtk 3.1.5 to resolve 'Symbol X has different size in shared object, consider re-linking' error

* Fri Jun 25 2021 wally <wally> 17.0-1.mga9
+ Revision: 1732189
- new version 17.0

* Fri Jan 01 2021 wally <wally> 0.15.0-9.mga8
+ Revision: 1667722
- rebuild for wxgtk pre 3.1.5 snapshot

* Wed Dec 02 2020 luigiwalser <luigiwalser> 0.15.0-8.mga8
+ Revision: 1651364
- rebuild for glew

* Sun Aug 16 2020 wally <wally> 0.15.0-7.mga8
+ Revision: 1614363
- rebuild for new wxgtk 3.1.4

* Wed Mar 04 2020 daviddavid <daviddavid> 0.15.0-6.mga8
+ Revision: 1553585
- port to python3

* Tue Feb 18 2020 umeabot <umeabot> 0.15.0-5.mga8
+ Revision: 1538027
- Mageia 8 Mass Rebuild

* Tue Nov 12 2019 wally <wally> 0.15.0-4.mga8
+ Revision: 1459485
- rebuild for wxgtk 3.1.3

* Mon Jul 08 2019 wally <wally> 0.15.0-3.mga8
+ Revision: 1419531
- rebuild for wxgtk 3.1.2 with 2.8 compatibility

* Sun Jun 30 2019 wally <wally> 0.15.0-2.mga8
+ Revision: 1416382
- rebuild with gtk3 enabled wxgtk 3.1.2
- add patch to fix build

* Sat Mar 09 2019 wally <wally> 0.15.0-1.mga7
+ Revision: 1373151
- new version 0.15.0 (based on .spec from Fedora)
+ dmorgan <dmorgan>
- imported package openmsx


* Wed Mar 16 2011 Stéphane Téletchéa <steletch@mandriva.org> 0.8.1-1mdv2011.0
+ Revision: 645371
- update to new version 0.8.1

* Sat Aug 28 2010 Zombie Ryushu <ryushu@mandriva.org> 0.8.0-1mdv2011.0
+ Revision: 573613
- Upgrade to 0.8.0
- Upgrade to 0.8.0

  + Götz Waschk <waschk@mandriva.org>
    - work around docdir listed twice problen on 2009.0
    - update build deps

* Fri Aug 07 2009 Götz Waschk <waschk@mandriva.org> 0.7.2-7mdv2010.0
+ Revision: 411055
- fix installation

* Fri Aug 07 2009 Zombie Ryushu <ryushu@mandriva.org> 0.7.2-6mdv2010.0
+ Revision: 411048
- Third try at fixing path issue
- Third try at fixing path issue

* Fri Aug 07 2009 Zombie Ryushu <ryushu@mandriva.org> 0.7.2-5mdv2010.0
+ Revision: 411033
- Third try at fixing path issue
- Third try at fixing path issue

* Thu Aug 06 2009 Zombie Ryushu <ryushu@mandriva.org> 0.7.2-4mdv2010.0
+ Revision: 410970
- Second try at fixing path issue
- Second try at fixing path issue

* Thu Aug 06 2009 Zombie Ryushu <ryushu@mandriva.org> 0.7.2-3mdv2010.0
+ Revision: 410562
- Fix Bad Data path error
- Fix Bad Data path error

* Wed Aug 05 2009 Zombie Ryushu <ryushu@mandriva.org> 0.7.2-2mdv2010.0
+ Revision: 410310
- Fix install stage files
- remove obsolete patch
- Upgrade to 0.7.2
- Upgrade to 0.7.2

* Thu Jan 15 2009 Zombie Ryushu <ryushu@mandriva.org> 0.7.0-2mdv2009.1
+ Revision: 329756
- Fix ttf Build requires
- Fix ttf Build requires
- Fix glew Build requires
- Fix glew Build requires
- Upgrade to version 0.7.0
- Upgrade to version 0.7.0

* Sat Dec 06 2008 Adam Williamson <awilliamson@mandriva.org> 0.6.3-2mdv2009.1
+ Revision: 311083
- rebuild for new tcl
- new license policy
- spec clean

* Tue Nov 11 2008 Zombie Ryushu <ryushu@mandriva.org> 0.6.3-1mdv2009.1
+ Revision: 302123
- New Version 0.6.3
- New version

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild

  + Pixel <pixel@mandriva.com>
    - rpm filetriggers deprecates update_menus/update_scrollkeeper/update_mime_database/update_icon_cache/update_desktop_database/post_install_gconf_schemas

* Thu Jan 03 2008 Thierry Vignaud <tv@mandriva.org> 0.6.2-2mdv2008.1
+ Revision: 142304
- auto-convert XDG menu entry
- kill re-definition of %%buildroot on Pixel's request
- do not package no more existing TODO
- new release
- Import openmsx

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Guillaume Rousse <guillomovitch@mandriva.org>
    - rebuild




* Mon Aug 07 2006 UTUMI Hirosi <utuhiro78@yahoo.co.jp> 0.6.1-1mdv2007.0
- new release

* Wed May 24 2006 Lenny Cartier <lenny@mandriva.com> 0.6.0-3mdk
- fix some buildrequires

* Mon May 15 2006 Thierry Vignaud <tvignaud@mandriva.com> 0.6.0-2mdk
- fix buildrequires for x86_64
- drop explicit requires (they're already automatically found by spec-helper
  anyway)

* Sun Jan 22 2006 UTUMI Hirosi <utuhiro78@yahoo.co.jp> 0.6.0-1mdk
- new release

* Sun Jul 03 2005 UTUMI Hirosi <utuhiro78@yahoo.co.jp> 0.5.2-1ut
- new release

* Mon Mar 21 2005 UTUMI Hirosi <utuhiro78@yahoo.co.jp> 0.5.1-1ut
- first spec for Mandrakelinux
